@@ -12,26 +12,60 @@
 #include <QStyle>
 #include <QStyleFactory>
 
+#include <KAboutData>
+#include <KCrash>
+#include <KIconTheme>
 #include <KLocalizedContext>
 #include <KLocalizedString>
-#include <KCrash>
-#include <KAboutData>
 
 #include <ThreadedDatabase>
 
 #include "asyncytmusic.h"
 
-Q_DECL_EXPORT int main(int argc, char *argv[])
-{
-    QApplication app(argc, argv);
+using namespace Qt::StringLiterals;
 
-    // set default style and icon theme
-    QIcon::setFallbackThemeName(QStringLiteral("breeze"));
-    if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE") && QQuickStyle::name().isEmpty()) {
+class StyleFallback
+{
+public:
+    StyleFallback()
+    {
+        if (QGuiApplication::instance()) {
+            qFatal("StyleFallback must be created before Q(Gui)Application");
+        }
+
+        KIconTheme::initTheme();
+
+        m_initialQuickControlsStyle = QQuickStyle::name();
+    }
+
+    void setup(QGuiApplication *app)
+    {
+        Q_ASSERT(app); // Force people to run this at the right time
+
+        // Check if the platformtheme or user set up a style for us
+        if (m_initialQuickControlsStyle != QQuickStyle::name()
+            || !qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
+            return;
+        }
+
+        qWarning() << "Detected that the platform did not set up a style, using defaults";
+
+        // platformtheme did not handle QtQuick styling, set everything to fallback values
         QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
         QApplication::setStyle(QStyleFactory::create(QStringLiteral("Breeze")));
+        QIcon::setThemeName(QStringLiteral("breeze"));
     }
 
+private:
+    QString m_initialQuickControlsStyle;
+};
+
+Q_DECL_EXPORT int main(int argc, char *argv[])
+{
+    StyleFallback fallback;
+    QApplication app(argc, argv);
+    fallback.setup(&app);
+
     // WORKAROUND: Force QtMultimedia gstreamer backend
     /*
       ffmpeg unfortunately loses the connection to youtube's servers with the following error message after ~2 minutes
